@@ -9,10 +9,10 @@ def __print_err__(text):
 
 
 @click.command()
-@click.argument('url', default=None)
+@click.argument('url', default='')
 def main(url):
-    if url is None:
-        __print_err__('You must provide the RCP url of a Tendermint full-node \nEg: python download_genesis.py '
+    if url is '':
+        __print_err__('You must provide the RCP url of a Tendermint full-node \nEg: download-tendermint-genesis '
                       'https://evmos-rpc.evmosis.com or https://evmos-rpc.polkachu.com')
 
     try:
